#include <creddy.h>

#include "creddy_common.h"

void display_main(options_t *opts) {
    if (opts->cert == NULL)
        usage(opts);

    char *show = opts->show;
    if (show == NULL)
        usage(opts);

    int show_issuer = 0;
    char *opt;

    while ((opt = strsep(&show, ",")) != NULL) {
        if (strcmp(opt, "issuer") == 0)
            show_issuer = 1;
        else if (strcmp(opt, "all") == 0) {
            show_issuer = 1;
        }
        else {
            printf("Error: Unknown option to --show: %s\n", opt);
            usage(opts);
        }
    }

    // first try ID cert
    creddy_id_t *id = creddy_id_from_file(opts->cert);
    if (id != NULL) {
        if (show_issuer) {
            char *issuer = creddy_id_issuer(id);
            puts(creddy_id_issuer(id));
        }

        creddy_id_free(id);
        return;
    }

    // then try attribute cert
    certificate_t *ac = lib->creds->create(lib->creds,
        CRED_CERTIFICATE, CERT_X509_AC,
        BUILD_FROM_FILE, opts->cert,
        BUILD_END
    );
    if (ac != NULL) {
        if (show_issuer)
            printf("%Y\n", ac->get_issuer(ac));

        DESTROY_IF(ac);
        return;
    }

    // give up if neither works
    errx(1, "Couldn't load %s as an ID or attribute cert", opts->cert);
}
